@@ -3,15 +3,29 @@
 use strict;
 use warnings;
 
+our $VERSION = '0.02';
+
 use App::CISetup::AppVeyor::ConfigUpdater;
 
 exit App::CISetup::AppVeyor::ConfigUpdater->new_with_options->run;
 
+# PODNAME: setup-appveyor-yml.pl
+
+# ABSTRACT: Tool for managing appveyor.yml files
+
 __END__
 
 =pod
 
-=head1 NAME - setup-appveyor-yml.pl
+=encoding UTF-8
+
+=head1 NAME
+
+setup-appveyor-yml.pl - Tool for managing appveyor.yml files
+
+=head1 VERSION
+
+version 0.02
 
 =head1 DESCRIPTION
 
@@ -117,4 +131,30 @@ The email address to which notifications should be sent. This is optional, and
 if you don't provide it, then no notification emails will be configured (but
 the default AppVeyor notifications will still be in place).
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<https://github.com/maxmind/App-CISetup/issues>.
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Mark Fowler <mark@twoshortplanks.com>
+
+=item *
+
+Dave Rolsky <autarch@urth.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2017 by MaxMind, Inc.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0 (GPL Compatible)
+
 =cut
